@@ -1,4 +1,5 @@
-from typing import Any, Callable, List, Union
+from typing import Any, Callable, List, Union  # noqa F401
+from schematics.models import Model  # noqa F401
 
 from collections import Counter
 from itertools import product
@@ -9,7 +10,6 @@ import re
 from pandas import DataFrame
 from pyparsing import ParseException
 from schematics.exceptions import DataError, ValidationError
-from schematics.models import Model
 import wrapt
 
 from hidebound.core.parser import AssetNameParser
@@ -753,3 +753,30 @@ def is_one_of(item, models):
             errors.add(str(e))
     error = '\n'.join(list(errors))
     raise ValidationError(error)
+
+
+@validate('''{} is not a legal cluster option type.
+Legal cluster option types: [bool, float, int, mapping, select, string]''')
+def is_cluster_option_type(item):
+    # type: (str) -> bool
+    '''
+    Validates that a given cluster option type is legal.
+    Legal types include:
+
+        * bool
+        * float
+        * int
+        * mapping
+        * select
+        * string
+
+    Args:
+        item (str): Cluster option type.
+
+    Raises:
+        ValidationError: If cluster option type is illegal.
+
+    Returns:
+        bool: Validity of cluster option type.
+    '''
+    return item in ['bool', 'float', 'int', 'mapping', 'select', 'string']
