@@ -1,5 +1,7 @@
 # app needs to come before api
 import hidebound.server.app  # noqa F401
 import hidebound.server.api  # noqa F401
+import hidebound.server.extension  # noqa F401
+import hidebound.server.extensions  # noqa F401
 import hidebound.server.components  # noqa F401
 import hidebound.server.server_tools  # noqa F401
