@@ -1,4 +1,4 @@
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, Optional, Union  # noqa F401
 
 from collections import OrderedDict
 from dataclasses import dataclass
@@ -58,13 +58,7 @@ def render_template(filename, parameters):
     Returns:
         bytes: HTML.
     '''
-    # path to templates inside pip package
     tempdir = lbt.relative_path(__file__, '../templates').as_posix()
-
-    # path to templates inside repo
-    if os.environ.get('REPO_ENV', 'False').lower() == 'true':
-        tempdir = lbt.relative_path(__file__, '../../../templates').as_posix()
-
     env = jinja2.Environment(
         loader=jinja2.FileSystemLoader(tempdir),
         keep_trailing_newline=True
@@ -296,7 +290,7 @@ def search(store, query, group_by_asset, client=requests):
 
 
 def format_config(
-    config, redact_regex='(_key|_id|url)$', redact_hash=False
+    config, redact_regex='(_key|_id|_token|url)$', redact_hash=False
 ):
     # type: (Dict[str, Any], str, bool) -> OrderedDict[str, Any]
     '''
@@ -305,7 +299,7 @@ def format_config(
     Args:
         config (dict): Configuration dictionary.
         redact_regex (str, optional): Regular expression that matches keys,
-            whose values are to be redacted. Default: "(_key|_id|url)$".
+            whose values are to be redacted. Default: "(_key|_id|_token|url)$".
         redact_hash (bool, optional): Whether to redact values with the string
             "REDACTED" or a hash of the value. Default: False.
 
@@ -332,12 +326,11 @@ def format_config(
         'include_regex',
         'exclude_regex',
         'write_mode',
-        'dask_workers',
-        'dask_cluster_type',
         'redact_regex',
         'redact_hash',
         'specification_files',
         'workflow',
+        'dask',
         'exporters',
         'webhooks',
     ]
